package de.datenkollektiv.spring.finder;

import java.util.List;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.jpa.AbstractJpaTests;
import org.springframework.transaction.annotation.Transactional;

import de.datenkollektiv.spring.finder.domain.LinkAttribute;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(locations = { "/sample-applicationContext.xml" })
@Transactional
public class LinkAttributeDaoTests extends AbstractJpaTests {

	@Autowired
    private AttributeDao linkAttributeDao;

    private LinkAttribute linkAttribute;
    private Long id;

    @Before
    public void onSetUpInTransaction() throws Exception {
        linkAttribute = new LinkAttribute("A", 12);
        linkAttributeDao.create(linkAttribute);
        assertNotNull(linkAttribute.getId());
        id = linkAttribute.getId();
        LinkAttribute person2 = new LinkAttribute("B", 13);
        linkAttributeDao.create(person2);
    }

    @Test
    public void testRead() throws Exception {
        LinkAttribute foundLinkAttribute = linkAttributeDao.read(id);
        assertEquals(linkAttribute.getWeight(), foundLinkAttribute.getWeight());
    }

    @Test
    public void testUpdate() {
        LinkAttribute foundLinkAttribute = linkAttributeDao.read(id);
        int updateWeight = 90;
        foundLinkAttribute.setWeight(updateWeight);
        LinkAttribute updatedLinkAttribute = linkAttributeDao.read(id);
        assertEquals(updateWeight, updatedLinkAttribute.getWeight());
    }

    @Test
    public void testDelete() {
        linkAttributeDao.delete(linkAttribute);
        assertNull(linkAttributeDao.read(id));
    }

    @Test
    public void testFindByName() throws Exception {
        List<LinkAttribute> byName = linkAttributeDao.findByName("A");
        assertEquals(1, byName.size());
        assertEquals(linkAttribute.getWeight(), byName.get(0).getWeight());
    }

}
